@@ -65,37 +65,38 @@ impl Body {
 
     /// Read the entirety of the body into a byte vector.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`BufRead::lines()`] or [`Body::read_chunks()`] to control how much of the body you process
+    /// at once.
     pub fn into_bytes(self) -> Vec<u8> {
         self.into_handle().into_bytes()
     }
 
     /// Read the entirety of the body into a `String`, interpreting the bytes as UTF-8.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`BufRead::lines()`] or [`Body::read_chunks()`] to control how much of the body you process
+    /// at once.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-body-utf8.md")
-    )]
+    /// If the body does not contain a valid UTF-8 string, this function will panic. To explicitly
+    /// handle the possibility of invalid UTF-8 data, use [`into_bytes()`][`Self::into_bytes()`] and
+    /// then convert the bytes explicitly with a function like [`String::from_utf8`].
     pub fn into_string(self) -> String {
         self.into_handle().into_string()
     }
 
     /// Append another body onto the end of this body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-append-constant-time.md")
-    )]
+    /// This operation is performed in amortized constant time, and so should always be preferred to
+    /// reading an entire body and then writing the same contents to another body.
     pub fn append(&mut self, other: Body) {
         // flush the write buffer of the destination body, so that we can use the append method on
         // the underlying handles. Unwrap, as `BodyHandle::flush` won't return actionable errors.
