@@ -219,10 +219,9 @@ impl Request {
     /// This method requires mutable access to this request because reading from and writing to the
     /// body can involve an HTTP connection.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/clones-body.md")
-    )]
+    /// This operation is potentially expensive if the body is large. Take care when using this
+    /// method on bodies with unknown sizes. Consider using methods like [`BufRead::lines()`] or
+    /// [`Body::read_chunks()`] to incrementally process a body while limiting the maximum size.
     ///
     /// # Examples
     ///
@@ -252,90 +251,90 @@ impl Request {
 
     /// Create a new `GET` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn get(url: impl ToUrl) -> Self {
         Self::new(Method::GET, url)
     }
 
     /// Create a new `HEAD` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn head(url: impl ToUrl) -> Self {
         Self::new(Method::HEAD, url)
     }
 
     /// Create a new `POST` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn post(url: impl ToUrl) -> Self {
         Self::new(Method::POST, url)
     }
 
     /// Create a new `PUT` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn put(url: impl ToUrl) -> Self {
         Self::new(Method::PUT, url)
     }
 
     /// Create a new `DELETE` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn delete(url: impl ToUrl) -> Self {
         Self::new(Method::DELETE, url)
     }
 
     /// Create a new `CONNECT` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn connect(url: impl ToUrl) -> Self {
         Self::new(Method::CONNECT, url)
     }
 
     /// Create a new `OPTIONS` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn options(url: impl ToUrl) -> Self {
         Self::new(Method::OPTIONS, url)
     }
 
     /// Create a new `TRACE` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn trace(url: impl ToUrl) -> Self {
         Self::new(Method::TRACE, url)
     }
 
     /// Create a new `PATCH` [`Request`] with the given URL, no headers, and an empty body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn patch(url: impl ToUrl) -> Self {
         Self::new(Method::PATCH, url)
     }
@@ -343,17 +342,15 @@ impl Request {
     /// Send the request to the given backend server, and return once the response headers have been
     /// received, or an error occurs.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/backend-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The backend argument can be any type that implements [`ToBackend`]; see that trait for
+    /// details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-responselimits.md")
-    )]
+    /// Panics if the backend response exceeds any of the limits configured by
+    /// [`ResponseLimits`][`crate::limits::ResponseLimits`].
     ///
     /// # Examples
     ///
@@ -403,10 +400,10 @@ impl Request {
     /// request may take longer than the Compute@Edge program is able to run, as the request will
     /// continue sending even after the program that intitiated it exits.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/backend-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The backend argument can be any type that implements [`ToBackend`]; see that trait for
+    /// details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -554,10 +551,8 @@ impl Request {
 
     /// Get a mutable reference to the body of this request.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/creates-empty-body.md")
-    )]
+    /// An empty body is returned if no body has been set, or if it has previously been returned by
+    /// a method like [`take_body()`][`Self::take_body()`].
     ///
     /// # Examples
     ///
@@ -627,14 +622,13 @@ impl Request {
     }
 
     /// Set the given value as the request's body.
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-argument.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
+    ///
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Argument type conversion
+    ///
+    /// See [`Body`] for details on which types can be used as a body.
     pub fn set_body(&mut self, body: impl Into<Body>) {
         self.body = Some(body.into());
     }
@@ -643,10 +637,8 @@ impl Request {
     ///
     /// After calling this method, this request will no longer have a body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/creates-empty-body.md")
-    )]
+    /// An empty body is returned if no body has been set, or if it has previously been returned by
+    /// a method like [`take_body()`][`Self::take_body()`].
     pub fn take_body(&mut self) -> Body {
         self.body.take().unwrap_or_else(|| Body::new())
     }
@@ -663,10 +655,8 @@ impl Request {
     ///
     /// If this request does not have a body, the appended body is set as the request's body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-append-constant-time.md")
-    )]
+    /// This operation is performed in amortized constant time, and so should always be preferred to
+    /// reading an entire body and then writing the same contents to another body.
     ///
     /// This method should be used when combining bodies that have not necessarily been read yet,
     /// such as the body of the client. To append contents that are already in memory as strings or
@@ -691,10 +681,13 @@ impl Request {
 
     /// Consume the request and return its body as a byte vector.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Examples
     ///
@@ -709,17 +702,20 @@ impl Request {
 
     /// Consume the request and return its body as a string.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-intobody-utf8.md")
-    )]
+    /// If the body does not contain a valid UTF-8 string, this function will panic. To explicitly
+    /// handle the possibility of invalid UTF-8 data, use
+    /// [`into_body_bytes()`][`Self::into_body_bytes()`] and then convert the bytes explicitly with
+    /// a function like [`String::from_utf8`].
     ///
     /// # Examples
     ///
@@ -735,10 +731,8 @@ impl Request {
 
     /// Consume the request and return its body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/creates-empty-body.md")
-    )]
+    /// An empty body is returned if no body has been set, or if it has previously been returned by
+    /// a method like [`take_body()`][`Self::take_body()`].
     pub fn into_body(self) -> Body {
         self.body.unwrap_or_else(|| Body::new())
     }
@@ -768,14 +762,12 @@ impl Request {
 
     /// Set the given string as the request's body with content type `text/plain; charset=UTF-8`.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-text-plain.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `text/plain; charset=utf-8`.
     ///
     /// # Examples
     ///
@@ -799,14 +791,12 @@ impl Request {
 
     /// Set the given string as the request's body with content type `text/html; charset=UTF-8`.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-text-html.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `text/html; charset=utf-8`.
     ///
     /// # Examples
     ///
@@ -826,17 +816,19 @@ impl Request {
     ///
     /// After calling this method, this request will no longer have a body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-takebody-utf8.md")
-    )]
+    /// If the body does not contain a valid UTF-8 string, this function will panic. To handle the
+    /// possibility of invalid UTF-8 data, use [`take_body_bytes()`][`Self::take_body_bytes()`] and
+    /// then convert the bytes with a function like [`String::from_utf8`].
     ///
     /// # Examples
     ///
@@ -883,14 +875,12 @@ impl Request {
 
     /// Set the given bytes as the request's body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-app-octet-stream.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `application/octet-stream`.
     ///
     /// # Examples
     ///
@@ -910,10 +900,13 @@ impl Request {
     ///
     /// After calling this method, this request will no longer have a body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Examples
     ///
@@ -971,10 +964,8 @@ impl Request {
     /// your own custom type, or use [`serde_json::Value`] to create untyped JSON values. See
     /// [`serde_json`] for details.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
     ///
     /// # Content type
     ///
@@ -1089,10 +1080,8 @@ impl Request {
     /// The given value must implement [`serde::Serialize`]; see the trait documentation for
     /// details.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
     ///
     /// # Content type
     ///
@@ -1131,10 +1120,8 @@ impl Request {
     /// Take the request body and attempt to parse it as a `application/x-www-form-urlencoded`
     /// formatted string.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/returns-deserializeowned.md")
-    )]
+    /// The return type chosen for this function must implement [`serde::de::Deserialize`] without
+    /// any non-static lifetimes; see the trait documentation for details.
     ///
     /// After calling this method, this request will no longer have a body.
     ///
@@ -1218,10 +1205,10 @@ impl Request {
 
     /// Returns whether the given header name is present in the request.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1247,17 +1234,16 @@ impl Request {
     /// values. See [`get_header_all_str()`][`Self::get_header_all_str()`] if you need to get all of
     /// the values.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-header-utf8.md")
-    )]
+    /// This method panics if the value of the header is not a valid UTF-8 string. To handle the
+    /// possibility of invalid UTF-8 data, use [`get_header()`][`Self::get_header()`] and then
+    /// convert the bytes with [`HeaderValue::to_str()`].
     ///
     /// # Examples
     ///
@@ -1284,10 +1270,10 @@ impl Request {
     /// values. See [`get_header_all()`][`Self::get_header_all()`] if you need to get all of the
     /// values.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1314,17 +1300,16 @@ impl Request {
 
     /// Get all values of a header as strings, or an empty vector if the header is not present.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-headers-utf8.md")
-    )]
+    /// This method panics if any of the header values are not valid UTF-8 strings. To handle the
+    /// possibility of non-UTF-8 data, use [`get_header_all()`][`Self::get_header_all()`] and then
+    /// convert the bytes with [`HeaderValue::to_str()`].
     ///
     /// # Examples
     ///
@@ -1350,10 +1335,10 @@ impl Request {
 
     /// Get an iterator of all the values of a header.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1451,10 +1436,11 @@ impl Request {
     /// Set a request header to the given value, discarding any previous values for the given
     /// header name.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-value-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name and value arguments can be any types that implement [`ToHeaderName`] and
+    /// [`ToHeaderValue`], respectively. See those traits for details on which types can be used and
+    /// when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1481,10 +1467,11 @@ impl Request {
     /// Unlike [`set_header()`][`Self::set_header()`], this does not discard existing values for the
     /// same header name.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-value-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name and value arguments can be any types that implement [`ToHeaderName`] and
+    /// [`ToHeaderValue`], respectively. See those traits for details on which types can be used and
+    /// when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1509,15 +1496,13 @@ impl Request {
     /// Remove all request headers of the given name, and return one of the removed header values
     /// if any were present.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/removes-one-header.md")
-    )]
+    /// If the header has multiple values, one is returned arbitrarily. To get all of the removed
+    /// header values, use [`get_header_all()`][`Self::get_header_all()`] before removing.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1536,22 +1521,19 @@ impl Request {
     /// Remove all request headers of the given name, and return one of the removed header values as
     /// a string if any were present.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/removes-one-header.md")
-    )]
+    /// If the header has multiple values, one is returned arbitrarily. To get all of the removed
+    /// header values, use [`get_header_all()`][`Self::get_header_all()`] before removing.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-remove-header-utf8.md")
-    )]
+    /// This method panics if the value of the header is not a valid UTF-8 string. To handle the
+    /// possibility of invalid UTF-8 data, use [`remove_header()`][`Self::remove_header()`] and then
+    /// convert the bytes with [`HeaderValue::to_str()`].
     ///
     /// # Examples
     ///
@@ -1613,10 +1595,10 @@ impl Request {
 
     /// Set the request method.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/method-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The method argument can be any type that implements [`ToMethod`]; see that trait for details
+    /// on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1687,10 +1669,10 @@ impl Request {
 
     /// Set the request URL.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/url-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The URL argument can be any type that implements [`ToUrl`]; see that trait for details on
+    /// which types can be used and when panics may arise during conversion.
     pub fn set_url(&mut self, url: impl ToUrl) {
         self.url = url.into_owned();
     }
@@ -1738,10 +1720,8 @@ impl Request {
 
     /// Attempt to parse the query component of the request URL into the specified datatype.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/returns-deserializeowned.md")
-    )]
+    /// The return type chosen for this function must implement [`serde::de::Deserialize`] without
+    /// any non-static lifetimes; see the trait documentation for details.
     ///
     /// # Errors
     ///
@@ -1940,7 +1920,8 @@ impl Request {
         self
     }
 
-    /// Override the caching behavior of this request to enable or disable PCI/HIPAA-compliant non-volatile caching.
+    /// Override the caching behavior of this request to enable or disable PCI/HIPAA-compliant
+    /// non-volatile caching.
     ///
     /// By default, this is `false`, which means the request may not be PCI/HIPAA-compliant. Set it
     /// to `true` to enable compliant caching.
@@ -2311,7 +2292,8 @@ impl SendError {
 
     /// Get the underlying cause of this `SendError`.
     ///
-    /// This is the same cause that would be returned by `err.source().downcast_ref::<SendErrorCause>()`, but more direct.
+    /// This is the same cause that would be returned by
+    /// `err.source().downcast_ref::<SendErrorCause>()`, but more direct.
     pub fn root_cause(&self) -> &SendErrorCause {
         &self.error
     }
