@@ -146,10 +146,9 @@ impl Response {
     /// This method requires mutable access to this response because reading from and writing to the
     /// body can involve an HTTP connection.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/clones-body.md")
-    )]
+    /// This operation is potentially expensive if the body is large. Take care when using this
+    /// method on bodies with unknown sizes. Consider using methods like [`BufRead::lines()`] or
+    /// [`Body::read_chunks()`] to incrementally process a body while limiting the maximum size.
     ///
     /// # Examples
     ///
@@ -178,10 +177,9 @@ impl Response {
 
     /// Create a new [`Response`] with the given value as the body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// See [`Body`] for details on which types can be used as a body.
     ///
     /// # Examples
     ///
@@ -203,10 +201,9 @@ impl Response {
 
     /// Create a new response with the given status code.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// See [`Body`] for details on which types can be used as a body.
     ///
     /// # Examples
     ///
@@ -291,10 +288,8 @@ impl Response {
 
     /// Get a mutable reference to the body of this response.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/creates-empty-body.md")
-    )]
+    /// An empty body is returned if no body has been set, or if it has previously been returned by
+    /// a method like [`take_body()`][`Self::take_body()`].
     ///
     /// # Examples
     ///
@@ -364,14 +359,13 @@ impl Response {
     }
 
     /// Set the given value as the response's body.
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-argument.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
+    ///
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Argument type conversion
+    ///
+    /// See [`Body`] for details on which types can be used as a body.
     pub fn set_body(&mut self, body: impl Into<Body>) {
         self.body = Some(body.into());
     }
@@ -380,10 +374,8 @@ impl Response {
     ///
     /// After calling this method, this response will no longer have a body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/creates-empty-body.md")
-    )]
+    /// An empty body is returned if no body has been set, or if it has previously been returned by
+    /// a method like [`take_body()`][`Self::take_body()`].
     pub fn take_body(&mut self) -> Body {
         self.body.take().unwrap_or_else(|| Body::new())
     }
@@ -400,10 +392,8 @@ impl Response {
     ///
     /// If this response does not have a body, the appended body is set as the response's body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/body-append-constant-time.md")
-    )]
+    /// This operation is performed in amortized constant time, and so should always be preferred to
+    /// reading an entire body and then writing the same contents to another body.
     ///
     /// This method should be used when combining bodies that have not necessarily been read yet,
     /// such as a body returned from a backend response. To append contents that are already in
@@ -429,11 +419,13 @@ impl Response {
 
     /// Consume the response and return its body as a byte vector.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
-    /// # Examples
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.  # Examples
     ///
     /// ```no_run
     /// # use fastly::Response;
@@ -446,17 +438,20 @@ impl Response {
 
     /// Consume the response and return its body as a string.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-intobody-utf8.md")
-    )]
+    /// If the body does not contain a valid UTF-8 string, this function will panic. To explicitly
+    /// handle the possibility of invalid UTF-8 data, use
+    /// [`into_body_bytes()`][`Self::into_body_bytes()`] and then convert the bytes explicitly with
+    /// a function like [`String::from_utf8`].
     ///
     /// # Examples
     ///
@@ -472,10 +467,8 @@ impl Response {
 
     /// Consume the response and return its body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/creates-empty-body.md")
-    )]
+    /// An empty body is returned if no body has been set, or if it has previously been returned by
+    /// a method like [`take_body()`][`Self::take_body()`].
     pub fn into_body(self) -> Body {
         self.body.unwrap_or_else(|| Body::new())
     }
@@ -508,14 +501,12 @@ impl Response {
 
     /// Set the given string as the response's body with content type `text/plain; charset=UTF-8`.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-text-plain.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `text/plain; charset=utf-8`.
     ///
     /// # Examples
     ///
@@ -539,14 +530,12 @@ impl Response {
 
     /// Set the given string as the request's body with content type `text/html; charset=UTF-8`.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-text-html.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `text/html; charset=utf-8`.
     ///
     /// # Examples
     ///
@@ -566,17 +555,19 @@ impl Response {
     ///
     /// After calling this method, this response will no longer have a body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-takebody-utf8.md")
-    )]
+    /// If the body does not contain a valid UTF-8 string, this function will panic. To handle the
+    /// possibility of invalid UTF-8 data, use [`take_body_bytes()`][`Self::take_body_bytes()`] and
+    /// then convert the bytes with a function like [`String::from_utf8`].
     ///
     /// # Examples
     ///
@@ -623,14 +614,12 @@ impl Response {
 
     /// Set the given bytes as the response's body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-app-octet-stream.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `application/octet-stream`.
     ///
     /// # Examples
     ///
@@ -650,10 +639,13 @@ impl Response {
     ///
     /// After calling this method, this response will no longer have a body.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/buffers-body-reqresp.md")
-    )]
+    /// # Memory usage
+    ///
+    /// This method will cause the entire body to be buffering in WebAssembly memory. You should
+    /// take care not to exceed the WebAssembly memory limits, and consider using methods like
+    /// [`read_body_lines()`][`Self::read_body_lines()`] or
+    /// [`read_body_chunks()`][`Self::read_body_chunks()`] to control how much of the body you
+    /// process at once.
     ///
     /// # Examples
     ///
@@ -711,14 +703,12 @@ impl Response {
     /// your own custom type, or use [`serde_json::Value`] to create untyped JSON values. See
     /// [`serde_json`] for details.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/sets-app-json.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
+    ///
+    /// # Content type
+    ///
+    /// This method sets the content type to `application/json`.
     ///
     /// # Errors
     ///
@@ -827,10 +817,8 @@ impl Response {
     /// The given value must implement [`serde::Serialize`]; see the trait documentation for
     /// details.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/discards-body.md")
-    )]
+    /// Any previous body that may have been set on the response is discarded. To add to an existing
+    /// body, use [`get_body_mut()`][`Self::get_body_mut()`] and write to the returned [`Body`].
     ///
     /// # Content type
     ///
@@ -869,10 +857,8 @@ impl Response {
     /// Take the response body and attempt to parse it as a `application/x-www-form-urlencoded`
     /// formatted string.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/returns-deserializeowned.md")
-    )]
+    /// The return type chosen for this function must implement [`serde::de::Deserialize`] without
+    /// any non-static lifetimes; see the trait documentation for details.
     ///
     /// After calling this method, this response will no longer have a body.
     ///
@@ -954,10 +940,9 @@ impl Response {
 
     /// Returns whether the given header name is present in the response.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -983,17 +968,16 @@ impl Response {
     /// values. See [`get_header_all_str()`][`Self::get_header_all_str()`] if you need to get all of
     /// the values.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-header-utf8.md")
-    )]
+    /// This method panics if the value of the header is not a valid UTF-8 string. To handle the
+    /// possibility of invalid UTF-8 data, use [`get_header()`][`Self::get_header()`] and then
+    /// convert the bytes with [`HeaderValue::to_str()`].
     ///
     /// # Examples
     ///
@@ -1021,10 +1005,10 @@ impl Response {
     /// values. See [`get_header_all()`][`Self::get_header_all()`] if you need to get all of the
     /// values.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1051,17 +1035,16 @@ impl Response {
 
     /// Get all values of a header as strings, or an empty vector if the header is not present.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-headers-utf8.md")
-    )]
+    /// This method panics if any of the header values are not valid UTF-8 strings. To handle the
+    /// possibility of non-UTF-8 data, use [`get_header_all()`][`Self::get_header_all()`] and then
+    /// convert the bytes with [`HeaderValue::to_str()`].
     ///
     /// # Examples
     ///
@@ -1087,10 +1070,10 @@ impl Response {
 
     /// Get an iterator of all the values of a header.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1191,10 +1174,11 @@ impl Response {
     /// Set a response header to the given value, discarding any previous values for the given
     /// header name.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-value-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name and value arguments can be any types that implement [`ToHeaderName`] and
+    /// [`ToHeaderValue`], respectively. See those traits for details on which types can be used and
+    /// when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1221,10 +1205,11 @@ impl Response {
     /// Unlike [`set_header()`][`Self::set_header()`], this does not discard existing values for the
     /// same header name.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-value-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name and value arguments can be any types that implement [`ToHeaderName`] and
+    /// [`ToHeaderValue`], respectively. See those traits for details on which types can be used and
+    /// when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1250,14 +1235,13 @@ impl Response {
     /// Remove all response headers of the given name, and return one of the removed header values
     /// if any were present.
     ///
-    /// If the header has multiple values, one is returned arbitrarily. To get all of the removed
-    /// header values, or to get a specific value, use
-    /// [`get_header_all()`][`Self::get_header_all()`].
+    /// If the header has multiple values, one is returned arbitrarily. To get all of the removed header
+    /// values, use [`get_header_all()`][`Self::get_header_all()`] before removing.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
@@ -1276,22 +1260,19 @@ impl Response {
     /// Remove all response headers of the given name, and return one of the removed header values
     /// as a string if any were present.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/removes-one-header.md")
-    )]
+    /// If the header has multiple values, one is returned arbitrarily. To get all of the removed
+    /// header values, use [`get_header_all()`][`Self::get_header_all()`] before removing.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/header-name-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The header name argument can be any type that implements [`ToHeaderName`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Panics
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/panics-reqresp-remove-header-utf8.md")
-    )]
+    /// This method panics if the value of the header is not a valid UTF-8 string. To handle the
+    /// possibility of invalid UTF-8 data, use [`remove_header()`][`Self::remove_header()`] and then
+    /// convert the bytes with [`HeaderValue::to_str()`].
     ///
     /// # Examples
     ///
@@ -1328,10 +1309,10 @@ impl Response {
 
     /// Set the HTTP status code of the response.
     ///
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../docs/snippets/statuscode-argument.md")
-    )]
+    /// # Argument type conversion
+    ///
+    /// The status code argument can be any type that implements [`ToStatusCode`]; see that trait
+    /// for details on which types can be used and when panics may arise during conversion.
     ///
     /// # Examples
     ///
