@@ -281,14 +281,13 @@ impl ResponseHandle {
         .expect("fastly_http_resp::header_values_set failed");
     }
 
-    #[cfg_attr(
-        feature = "unstable-doc",
-        doc(include = "../../../docs/snippets/handle-get-header-value.md")
-    )]
-    #[cfg_attr(
-        not(feature = "unstable-doc"),
-        doc = "Placeholder doc to suppress warnings without `unstable-doc` feature"
-    )]
+    /// Get the value of a header, or `None` if the header is not present.
+    ///
+    /// If there are multiple values for the header, only one is returned. See
+    /// [`get_header_values()`][`Self::get_header_values()`] if you need to get all of the values.
+    ///
+    /// If the value is longer than `max_len`, this will return a [`BufferSizeError`]; you can retry
+    /// with a larger buffer size if necessary.
     pub fn get_header_value(
         &self,
         name: &HeaderName,
